if ( exist('OCTAVE_VERSION') ~= 0 )
     load -force btk_connectivity_matrix;
     load -force btk_balance_matrix;
else
     load btk_connectivity_matrix.mat;
     load btk_balance_matrix.mat;
end
% "(1,1)" indicates the aldehyde carbon of D-glucose.
% "(1,1)" means "1+i".
s = 1+i;
% "(15,1)" indicates the carbon of CO2.
% "(15,1)" means "15+i".
d = 15+i; 
% "CM" means connectivity matrix. 
% "btk_route" computes all the paths connecting "s" to "d".
% "xcell" is a cell array consisting of row number sequences.
% The row number sequences correspond to the above paths between "s" to "d".
xcell = btk_route(CM, s, d);
% "r" is the number of paths.
[r,c] = size(xcell);
disp(' ');
disp(['Number of paths: ', int2str(r)]);
% "path_length" shows length of paths as the number of processes.
path_length = zeros(r,1);
i0 = 1;
while ( i0 <= r )
     [ri0, ci0] = size(xcell{i0,1});
     path_length(i0,1) = ci0;
     i0 = i0 + 1;
end
disp(' ');
disp(['Maximal path length: ', int2str(max(path_length))]);
disp(['Minimum path length: ', int2str(min(path_length))]);
disp(['Average path length: ', num2str(sum(path_length)/r)]);
w = max(max(real(BM)));
path_balance = zeros(r,w);
i0 = 1;
while ( i0 <= r )
% "btk_calc_balance" calculates chemical balance of a process sequence using balance matrix "BM".
% "path_balance" is a summary of chemical balance of process sequences.
     path_balance(i0,:) = btk_calc_balance(CM(xcell{i0,1},3).', BM, w);
     i0 = i0 + 1;
end
% Metabolite number of CO2 is 15.
iCO2 = 15;
% "x_CO2" shows CO2 production.
x_CO2 = path_balance(:,iCO2);
disp(' ');
disp(['Maximal CO2 production: ', num2str(max(x_CO2))]);
disp(['Minimum CO2 production: ', num2str(min(x_CO2))]);
disp(['Average CO2 production: ', num2str(sum(x_CO2)/r)]);
% Metabolite number of ATP is 33.
iATP = 33;
% Metabolite number of GTP is 35.
iGTP = 35;
% Metabolite number of NADH is 40.
iNADH = 40;
% Metabolite number of FADH2 is 38.
iFADH2 = 38;
% "x_ATP_eq" shows ATP equivalent formation.
x_ATP_eq(:,1)=path_balance(:,iATP)+path_balance(:,iGTP)+2.5*path_balance(:,iNADH)+1.5*path_balance(:,iFADH2);
disp(' ');
disp(['Maximal ATP equivalent formation: ', num2str(max(x_ATP_eq))]);
disp(['Minimum ATP equivalent formation: ', num2str(min(x_ATP_eq))]);
disp(['Average ATP equivalent formation: ', num2str(sum(x_ATP_eq)/r)]);

maxpl = max(path_length);
path_distrib = zeros(maxpl,1);
i0 = 1;
while ( i0 <= r )
     path_distrib(path_length(i0,1),1) = path_distrib(path_length(i0,1),1) + 1;
     i0 = i0 + 1;
end

subplot(2,2,1);
plot([1:maxpl].', path_distrib, 'o');
     xlabel('Length of Paths');
     ylabel('Number of Paths');
%pause;

subplot(2,2,2);
plot(path_length, x_CO2, 'o');
     xlabel('Length of Paths');
     ylabel('CO2 Production');
%pause;

subplot(2,2,3);
plot(path_length, x_ATP_eq, 'o');
     xlabel('Length of Paths');
     ylabel('ATP Equivalent Formation');
%pause;

subplot(2,2,4);
plot(x_CO2, x_ATP_eq, 'o');
     xlabel('CO2 Production');
     ylabel('ATP Equivalent Formation');
